package com.persagy.energy.utils

import net.minidev.json.JSONObject
import net.minidev.json.parser.JSONParser
import org.apache.kafka.clients.producer.{KafkaProducer, ProducerRecord}

import java.util.Properties
import scala.io.BufferedSource

object KafkaUtil {

  val dev_host: String = "192.168.4.7:9092,192.168.4.8:9092,192.168.4.9:9092"
  val test_host: String = "192.168.100.84:9092,192.168.100.75:9092,192.168.100.147:9092"
  val topic: String = "energy_data"
//  val file_path: String = "/Users/king/Documents/persagy/dw/log.log2021-01-11-15.log";
  val filePath: String = "/Users/king/Downloads/energy-1d.txt"
  val outPath: String = "/Users/king/Downloads/energy-1d-to-hdfs1.txt"

  def kafkaConsumerProperties(): Properties = {
    val properties = new Properties()
    properties.setProperty("bootstrap.servers", dev_host)
    properties.setProperty("key.deserializer", "org.apache.kafka.common.serialization.StringDeserializer")
    properties.setProperty("value.deserializer", "org.apache.kafka.common.serialization.StringDeserializer")
    properties.setProperty("auto.offset.reset", "latest")
    properties
  }

  def kafkaProducerProperties(): Properties = {
    val properties = new Properties()
    properties.setProperty("bootstrap.servers", dev_host)
    properties.setProperty("key.serializer", "org.apache.kafka.common.serialization.StringSerializer")
    properties.setProperty("value.serializer", "org.apache.kafka.common.serialization.StringSerializer")
    properties
  }

  def sendMessageToKafka(topic: String): Unit = {

    /** 创建一个 KafkaProducer，发送数据 */
    val producer = new KafkaProducer[String, String](kafkaProducerProperties())

    /** 从文件读取数据，逐条发送 */
    val bufferedSource: BufferedSource = scala.io.Source.fromFile(filePath)

    for (line <- bufferedSource.getLines()) {

      val parser = new JSONParser(1)
      val nObject: JSONObject = parser.parse(line).asInstanceOf[JSONObject]

      val energyModelSign: String = nObject.get("energyModelSign").toString
      val energyModelNodeSign: String = nObject.get("energyModelNodeSign").toString
      val dataTime: String = DTUtils.timestampConverter("yyyyMMddHHmmss", nObject.get("data_time").toString, 0L).toString
      val dataValue: String = nObject.get("data_value").toString
      val building: String = nObject.get("building").toString

      val result: String = building + ":" + energyModelSign + ":" + energyModelNodeSign + ":" + dataTime + "\t" + dataValue
      println(result)
      val record = new ProducerRecord[String, String](topic, result)
      producer.send(record)
//      Thread.sleep(1000L)
    }
  }

}
